/*
*	nokia_3310_lcd.h
*/

#ifndef _NOKIA_3310_LCD_H
#define _NOKIA_3310_LCD_H

#include <inttypes.h>
#include <avr/pgmspace.h>

#define USE_GRAPHIC
#define USE_BITMAP

// Define SPI port
#define LCD_DC  PB2
#define LCD_RST PB0

#define SPI_CS  PD7
#define SPI_CS_PORT  PORTD
#define SPI_CS_DDR  DDRD

#define SPI_MOSI PB3
#define SPI_SCK PB5

#define LCD_BL  PD4		// Backlight control (not used from nokia_3310_lcd library)

//display mode -- normal / highlight
#define MENU_NORMAL	0
#define MENU_HIGHLIGHT 1
#define PIXEL_OFF 0
#define PIXEL_ON  1
#define PIXEL_XOR 2

void nokia_3310_lcd_writeCommand( unsigned char );
void nokia_3310_lcd_writeData( unsigned char );

// Init/Clear/position functions
void nokia_3310_lcd_init(void);
void nokia_3310_lcd_write(uint8_t byte);
void nokia_3310_lcd_clear(void);
void nokia_3310_lcd_gotoXY(unsigned char x, unsigned char y);
void nokia_3310_lcd_update(void);

// String and character functions
void nokia_3310_lcd_writeString(unsigned char x,unsigned char y,char *s, char mode); 
void nokia_3310_lcd_writeStringP(unsigned char x,unsigned char y, const char *s, char mode); 
void nokia_3310_lcd_writeStringBig(unsigned char x,unsigned char y, char *string, char mode);
void nokia_3310_lcd_writeCharBig (unsigned char x,unsigned char y, unsigned char ch, char mode);
void nokia_3310_lcd_writeChar(unsigned char ch, char mode);

// Bitmap functions
#ifdef USE_BITMAP
	void nokia_3310_lcd_drawBitmap(unsigned char x,unsigned char y,unsigned char *map, unsigned char size_x,unsigned char size_y);
	void nokia_3310_lcd_drawBitmapP(unsigned char x,unsigned char y, const prog_char *map, unsigned char size_x,unsigned char size_y);
	void nokia_3310_lcd_clearBitmap(unsigned char x,unsigned char y, unsigned char size_x,unsigned char size_y);
#endif

// Graphic functions
#ifdef  USE_GRAPHIC
	void nokia_3310_lcd_setPixel( unsigned char x, unsigned char y, unsigned char c );
	void nokia_3310_lcd_drawLine(unsigned char x1, unsigned char y1, unsigned char x2, unsigned char y2, unsigned char c);
	void nokia_3310_lcd_drawRectangle(unsigned char x1, unsigned char y1, unsigned char x2, unsigned char y2, unsigned char c);
	void nokia_3310_lcd_drawFilledRectangle(unsigned char x1, unsigned char y1, unsigned char x2, unsigned char y2, unsigned char c);
	void nokia_3310_lcd_drawCircle(unsigned char xc, unsigned char yc,	unsigned char r, unsigned char c);
#endif

#endif //_NOKIA_3310_LCD_H

